<?php
namespace SM\Controller;

use SM\Controller\SMCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use SM\Service\Sm00024000ModeloDocumentoService;
use SM\Traits\TResponse;

class Sm00024000ModeloDocumentoController extends SMCrud
{

    use TResponse;

    protected $ModeloDocumentoService;

    public function __construct($crudService, $environment, Sm00024000ModeloDocumentoService $ModeloDocumentoService)
    {
        parent::__construct($crudService, $environment);
        $this->ModeloDocumentoService=$ModeloDocumentoService;
    }

    public function getInformacoesModeloDocumento()
    {
        try {
            $data = $this->ModeloDocumentoService->getInformacoesModeloDocumento();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getTabAnexo(Request $request)
    {
        try {
            $data = $this->ModeloDocumentoService->getTabAnexo($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function inserirModeloDocumento(Request $request)
    {
        try {
            $this->ModeloDocumentoService->inserirModeloDocumento($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function inserirModeloDocumentoIdioma(Request $request)
    {
        try {
            $this->ModeloDocumentoService->inserirModeloDocumentoIdioma($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function saveTabModeloDocumento(Request $request)
    {
        try {
            $this->ModeloDocumentoService->saveTabModeloDocumento($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deletarModeloDocumento(Request $request)
    {
        try {
            $this->ModeloDocumentoService->deletarModeloDocumento($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deletarAnexo(DTO\Request $request)
    {
        try {
            $this->ModeloDocumentoService->deletarAnexo($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function downloadAnexoModeloDocumento(Request $request)
    {
        $params = $request->getParameters();
        $idpadrao          = $params["idpadrao"];
        $nrmodelodocidioma = $params["nrmodelodocidioma"];
        $nrseqmoddocfct    = $params["nrseqmoddocfct"];
        $this->ModeloDocumentoService->downloadAnexoModeloDocumento($idpadrao, $nrmodelodocidioma, $nrseqmoddocfct);
    }

    public function deletarAnexoModeloDocumento(Request $request)
    {
        try {
            $this->ModeloDocumentoService->limparAnexoModeloDocumento($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
