<?php

namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use SM\Traits\TQuery;

class DashboardFactory
{

    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getApprovedContracts($parametros)
    {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);

        $sql = "SELECT GRAF.*
                  FROM (SELECT FCT_CONTRATO.NRTIPOORCAMENTO, FCT_TIPOORCAMENTO.NMTIPOORCAMENTO, COUNT(FCT_APROVACONTRATO.NRSEQAPROVCONT) AS QUANTIDADE,
                        SUM(FCT_ITEMCONTRATO.VRTOTITEMCONT) AS VALOR
                          FROM FCT_APROVACONTRATO
                          JOIN FCT_CONTRATO
                           ON FCT_CONTRATO.NRSEQCONTRATO = FCT_APROVACONTRATO.NRSEQCONTRATO
                          AND FCT_CONTRATO.NRORG = FCT_APROVACONTRATO.NRORG
                         JOIN FCT_ITEMCONTRATO
                          ON  FCT_ITEMCONTRATO.NRSEQCONTRATO = FCT_CONTRATO.NRSEQCONTRATO
                          JOIN FCT_TIPOORCAMENTO
                            ON FCT_TIPOORCAMENTO.NRTIPOORCAMENTO = FCT_CONTRATO.NRTIPOORCAMENTO
                           AND FCT_TIPOORCAMENTO.NRORG = FCT_CONTRATO.NRORG
                         WHERE FCT_APROVACONTRATO.DTAPROVCONTR BETWEEN NVL(:DTINICIO, SYSDATE-30) AND NVL(:DTFINAL, SYSDATE)
                         AND FCT_APROVACONTRATO.IDAPROCCONTR = 'A'
                         AND FCT_CONTRATO.IDATIVO = 'S'
                         GROUP BY FCT_CONTRATO.NRTIPOORCAMENTO, FCT_TIPOORCAMENTO.NMTIPOORCAMENTO
                         ORDER BY QUANTIDADE DESC) GRAF
                         WHERE ROWNUM <= 5";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function getTerminatedContracts($parametros)
    {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);

        $sql = "SELECT GRAF.*
                  FROM (SELECT FCT_CONTRATO.NRTIPOORCAMENTO, FCT_TIPOORCAMENTO.NMTIPOORCAMENTO, COUNT(FCT_CONTRATO.NRSEQCONTRATO) AS QUANTIDADE,
                        SUM(FCT_ITEMCONTRATO.VRTOTITEMCONT) AS VALOR
                          FROM FCT_CONTRATO
                          JOIN FCT_ITEMCONTRATO
                          ON  FCT_ITEMCONTRATO.NRSEQCONTRATO = FCT_CONTRATO.NRSEQCONTRATO
                          JOIN FCT_TIPOORCAMENTO
                            ON FCT_TIPOORCAMENTO.NRTIPOORCAMENTO = FCT_CONTRATO.NRTIPOORCAMENTO
                           AND FCT_TIPOORCAMENTO.NRORG = FCT_CONTRATO.NRORG
                         WHERE FCT_CONTRATO.DTRECISAOCONTR BETWEEN NVL(:DTINICIO, SYSDATE-30) AND NVL(:DTFINAL, SYSDATE)
                           AND FCT_CONTRATO.IDSITUACAOCONTRATO IN ('E', 'R')
                         GROUP BY FCT_CONTRATO.NRTIPOORCAMENTO, FCT_TIPOORCAMENTO.NMTIPOORCAMENTO
                         ORDER BY QUANTIDADE DESC) GRAF
                         WHERE ROWNUM <= 5";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function getRenegotiatedContracts($parametros)
    {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);

        $sql = "SELECT GRAF.*
                    FROM (SELECT FCT_CONTRATO.NRTIPOORCAMENTO, FCT_TIPOORCAMENTO.NMTIPOORCAMENTO, COUNT(FCT_CONTRATO.NRSEQCONTRATO) AS QUANTIDADE,
                            SUM(FCT_ITEMCONTRATO.VRTOTITEMCONT) AS VALOR
                            FROM FCT_CONTRATO
                            JOIN FCT_ITEMCONTRATO
                            ON  FCT_ITEMCONTRATO.NRSEQCONTRATO = FCT_CONTRATO.NRSEQCONTRATO
                            JOIN FCT_TIPOORCAMENTO
                            ON FCT_TIPOORCAMENTO.NRTIPOORCAMENTO = FCT_CONTRATO.NRTIPOORCAMENTO
                            AND FCT_TIPOORCAMENTO.NRORG = FCT_CONTRATO.NRORG
                        WHERE FCT_CONTRATO.DTINCLUSAO BETWEEN NVL(:DTINICIO, SYSDATE-30) AND NVL(:DTFINAL, SYSDATE)
                            AND FCT_CONTRATO.NRSEQCONTRATOPAI IS NOT NULL
                            AND FCT_CONTRATO.NRVERSAOCONTRATO > 1
                            AND FCT_CONTRATO.IDATIVO = 'S'
                        GROUP BY FCT_CONTRATO.NRTIPOORCAMENTO, FCT_TIPOORCAMENTO.NMTIPOORCAMENTO
                        ORDER BY QUANTIDADE DESC) GRAF
                        WHERE ROWNUM <= 5";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function getContractsCloseToExpiration()
    {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);


        $sql = "SELECT NRSEQCONTRATO,
                    NRCONTRATOFCT,
                    NRPARCNEGOCIO,
                    NMSECUNDARIPARC,
                    DTFINVIGENCONT,
                    DTPADREAJCONT,
                    QTDIASVENCPRAZO,
                    CASE
                        WHEN QTDIASVENCPRAZO < 0 THEN
                            'Prazo venceu em ' || QTDIASVENCPRAZO * -1 || ' dias (' || DTFINVIGENCONT || ')'
                        WHEN QTDIASVENCPRAZO = 0 THEN
                            'Prazo vence hoje (' || DTFINVIGENCONT || ')'
                        ELSE
                            'Prazo vence em ' || QTDIASVENCPRAZO || ' dias (' || DTFINVIGENCONT || ')'
                    END AS STRPRAZO,
                    QTDIASVENCREAJ,
                    CASE
                        WHEN QTDIASVENCREAJ < 0 THEN
                            'Reajuste ' || QTDIASVENCREAJ * -1 || ' dias atrasado (' || DTPADREAJCONT || ')'
                        WHEN QTDIASVENCREAJ = 0 THEN
                            'Reajustar hoje (' || DTPADREAJCONT || ')'
                        ELSE
                            'Reajustar em ' || QTDIASVENCREAJ || ' dias (' || DTPADREAJCONT || ')'
                    END AS STRREAJ
                FROM (
                SELECT CONT.NRSEQCONTRATO,
                        CONT.NRCONTRATOFCT,
                        CONT.NRPARCNEGOCIO,
                        PARC.NMSECUNDARIPARC,
                        TO_CHAR(NVL(CONT.DTFINVIGENCONT, CONT.DTFIMCONTRATO), 'DD/MM/YYYY') AS DTFINVIGENCONT,
                        TO_CHAR(CONT.DTPADREAJCONT, 'DD/MM/YYYY') AS DTPADREAJCONT,
                        TRUNC(NVL(CONT.DTFINVIGENCONT, CONT.DTFIMCONTRATO)) - TRUNC(SYSDATE) AS QTDIASVENCPRAZO,
                        TRUNC(CONT.DTPADREAJCONT) - TRUNC(SYSDATE) AS QTDIASVENCREAJ
                    FROM FCT_CONTRATO CONT
                    INNER JOIN PARCNEGOCIO PARC
                    ON CONT.NRPARCNEGOCIO = PARC.NRPARCNEGOCIO
                    WHERE CONT.IDATIVO = 'S'
                    AND CONT.IDSITUACAOCONTRATO IN ('A', 'S')
                    AND (
                        (NVL(CONT.DTFINVIGENCONT, CONT.DTFIMCONTRATO) <= TRUNC(SYSDATE+30)) OR
                        (TRUNC(CONT.DTPADREAJCONT) <= TRUNC(SYSDATE+30))
                    )
                    ORDER BY CONT.DTPADREAJCONT, NVL(CONT.DTFINVIGENCONT, CONT.DTFIMCONTRATO)
                )";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getContractsPendingBilling($parametros)
    {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);

        $sql = "SELECT CONT.NRSEQCONTRATO,
                        CONT.NRCONTRATOFCT,
                        CONT.NRPARCNEGOCIO,
                        PARC.NMSECUNDARIPARC,
                        FAT.NRFATURACONT,
                        TO_CHAR(FAT.DTLIMITEAPU, 'DD/MM/YYYY') AS DTLIMITEAPU,
                        'Data Limite de Apuração - ' || TO_CHAR(FAT.DTLIMITEAPU, 'DD/MM/YYYY') AS STRDTLIMITE
                    FROM FCT_FATURACONT FAT
                INNER JOIN FCT_RELACAGRUPCONTFAT REL
                    ON FAT.NRFATURACONT = REL.NRFATURACONT
                INNER JOIN FCT_CONTRATO CONT
                    ON REL.NRSEQCONTRATO = CONT.NRSEQCONTRATO
                INNER JOIN PARCNEGOCIO PARC
                    ON CONT.NRPARCNEGOCIO = PARC.NRPARCNEGOCIO
                WHERE FAT.IDSITUACAO IN ('1', '6')
                    AND TRUNC(FAT.DTLIMITEAPU) BETWEEN TRUNC(NVL(TO_DATE(:DTINI, 'DD/MM/YYYY'),SYSDATE-30)) AND TRUNC(NVL(TO_DATE(:DTFIN, 'DD/MM/YYYY'), SYSDATE))
                ORDER BY FAT.DTLIMITEAPU";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function getChartBusinessPartner($parametros)
    {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);


        $sql = "SELECT GRAF.*
                	FROM (SELECT FCT_APURACAO.NRPARCNEGOCIO, PARCNEGOCIO.NMSECUNDARIPARC, SUM(FCT_APURACAO.VRAPURACAO) AS VALOR
                	  FROM FCT_FATURACONT
                	  JOIN FCT_RELACAPURACAOFATURA
                	    ON FCT_RELACAPURACAOFATURA.NRFATURACONT = FCT_FATURACONT.NRFATURACONT
                	   AND FCT_RELACAPURACAOFATURA.NRORG = FCT_FATURACONT.NRORG
                	  JOIN FCT_APURACAO
                	    ON FCT_RELACAPURACAOFATURA.NRAPURACAO = FCT_APURACAO.NRAPURACAO
                	   AND FCT_RELACAPURACAOFATURA.NRORG = FCT_APURACAO.NRORG
                	  JOIN PARCNEGOCIO
                	    ON PARCNEGOCIO.NRPARCNEGOCIO = FCT_APURACAO.NRPARCNEGOCIO
                	   AND PARCNEGOCIO.NRORG = FCT_APURACAO.NRORG
                	 WHERE FCT_APURACAO.DTINCLUSAO BETWEEN NVL(:DTINICIO, SYSDATE-30) AND NVL(:DTFINAL, SYSDATE)
                	 GROUP BY FCT_APURACAO.NRPARCNEGOCIO, PARCNEGOCIO.NMSECUNDARIPARC
                	 ORDER BY VALOR DESC) GRAF
                	 WHERE ROWNUM <= 5";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function getChartBillingScope($parametros)
    {
        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);

        $sql = "SELECT GRAF.*
                  FROM (SELECT FCT_CONTRATO.NRTIPOORCAMENTO, FCT_TIPOORCAMENTO.NMTIPOORCAMENTO, SUM(FCT_APURACAO.VRAPURACAO) AS VALOR
                      FROM FCT_FATURACONT
                      JOIN FCT_RELACAPURACAOFATURA
                        ON FCT_RELACAPURACAOFATURA.NRFATURACONT = FCT_FATURACONT.NRFATURACONT
                       AND FCT_RELACAPURACAOFATURA.NRORG = FCT_FATURACONT.NRORG
                      JOIN FCT_APURACAO
                        ON FCT_RELACAPURACAOFATURA.NRAPURACAO = FCT_APURACAO.NRAPURACAO
                       AND FCT_RELACAPURACAOFATURA.NRORG = FCT_APURACAO.NRORG
                      JOIN FCT_RELACAGRUPCONTFAT
                        ON FCT_RELACAGRUPCONTFAT.NRFATURACONT = FCT_FATURACONT.NRFATURACONT
                       AND FCT_RELACAGRUPCONTFAT.NRORG = FCT_FATURACONT.NRORG
                      JOIN FCT_CONTRATO
                        ON FCT_CONTRATO.NRSEQCONTRATO = FCT_RELACAGRUPCONTFAT.NRSEQCONTRATO
                       AND FCT_CONTRATO.NRORG = FCT_RELACAGRUPCONTFAT.NRORG
                      JOIN FCT_TIPOORCAMENTO
                        ON FCT_TIPOORCAMENTO.NRTIPOORCAMENTO = FCT_CONTRATO.NRTIPOORCAMENTO
                       AND FCT_TIPOORCAMENTO.NRORG = FCT_CONTRATO.NRORG
                     WHERE FCT_APURACAO.DTINCLUSAO BETWEEN NVL(:DTINICIO, SYSDATE-30) AND NVL(:DTFINAL, SYSDATE)
                     GROUP BY FCT_CONTRATO.NRTIPOORCAMENTO, FCT_TIPOORCAMENTO.NMTIPOORCAMENTO
                     ORDER BY VALOR DESC) GRAF
                     WHERE ROWNUM <= 5  ";



        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function getChartContractItems($parametros)
    {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);

        $sql = "SELECT GRAF.*
                  FROM (SELECT FCT_ITEMCONTRATO.CDSERVORCA, FCT_ITEMCONTRATO.NMITEMCONTRATO, SUM(FCT_ITFATURACONT.VRFATURADO) AS VALOR
                          FROM FCT_FATURACONT
                          JOIN FCT_RELACAPURACAOFATURA
                            ON FCT_RELACAPURACAOFATURA.NRFATURACONT = FCT_FATURACONT.NRFATURACONT
                           AND FCT_RELACAPURACAOFATURA.NRORG = FCT_FATURACONT.NRORG
                          JOIN FCT_APURACAO
                            ON FCT_RELACAPURACAOFATURA.NRAPURACAO = FCT_APURACAO.NRAPURACAO
                           AND FCT_RELACAPURACAOFATURA.NRORG = FCT_APURACAO.NRORG
                          JOIN FCT_RELACAGRUPCONTFAT
                            ON FCT_RELACAGRUPCONTFAT.NRFATURACONT = FCT_FATURACONT.NRFATURACONT
                           AND FCT_RELACAGRUPCONTFAT.NRORG = FCT_FATURACONT.NRORG
                          JOIN FCT_CONTRATO
                            ON FCT_CONTRATO.NRSEQCONTRATO = FCT_RELACAGRUPCONTFAT.NRSEQCONTRATO
                           AND FCT_CONTRATO.NRORG = FCT_RELACAGRUPCONTFAT.NRORG
                          JOIN FCT_ITFATURACONT
                            ON FCT_ITFATURACONT.NRSEQCONTRATO = FCT_CONTRATO.NRSEQCONTRATO
                           AND FCT_ITFATURACONT.NRFATURACONT = FCT_FATURACONT.NRFATURACONT
                           AND FCT_ITFATURACONT.NRORG = FCT_CONTRATO.NRORG
                          JOIN FCT_ITEMCONTRATO
                            ON FCT_ITEMCONTRATO.NRITEMOCONTRATO = FCT_ITFATURACONT.NRITEMOCONTRATO
                           AND FCT_ITEMCONTRATO.NRORG = FCT_ITFATURACONT.NRORG
                         WHERE FCT_APURACAO.DTINCLUSAO BETWEEN NVL(:DTINICIO, SYSDATE-30) AND NVL(:DTFINAL, SYSDATE)
                         GROUP BY FCT_ITEMCONTRATO.CDSERVORCA, FCT_ITEMCONTRATO.NMITEMCONTRATO
                         ORDER BY VALOR DESC) GRAF
                         WHERE ROWNUM <= 5";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function getMonthlyHistory()
    {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);


        $sql = "SELECT TO_CHAR(FCT_APURACAO.DTINCLUSAO, 'MM/YYYY') AS MES, SUM(FCT_APURACAO.VRAPURACAO) AS VALOR
                    FROM FCT_FATURACONT
                    JOIN FCT_RELACAPURACAOFATURA
                        ON FCT_RELACAPURACAOFATURA.NRFATURACONT = FCT_FATURACONT.NRFATURACONT
                    AND FCT_RELACAPURACAOFATURA.NRORG = FCT_FATURACONT.NRORG
                    JOIN FCT_APURACAO
                        ON FCT_RELACAPURACAOFATURA.NRAPURACAO = FCT_APURACAO.NRAPURACAO
                    AND FCT_RELACAPURACAOFATURA.NRORG = FCT_APURACAO.NRORG
                    WHERE FCT_APURACAO.DTINCLUSAO BETWEEN SYSDATE-365 AND SYSDATE
                    GROUP BY TO_CHAR(FCT_APURACAO.DTINCLUSAO, 'MM/YYYY')
                    ORDER BY MES";


        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }

    public function getBusinessPartnerDetailed($parametros)
    {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);

        $sql = " SELECT FCT_APURACAO.NRPARCNEGOCIO, PARCNEGOCIO.NMSECUNDARIPARC, SUM(FCT_APURACAO.VRAPURACAO) AS VALOR
                    FROM FCT_FATURACONT
                    JOIN FCT_RELACAPURACAOFATURA
                        ON FCT_RELACAPURACAOFATURA.NRFATURACONT = FCT_FATURACONT.NRFATURACONT
                    AND FCT_RELACAPURACAOFATURA.NRORG = FCT_FATURACONT.NRORG
                    JOIN FCT_APURACAO
                        ON FCT_RELACAPURACAOFATURA.NRAPURACAO = FCT_APURACAO.NRAPURACAO
                    AND FCT_RELACAPURACAOFATURA.NRORG = FCT_APURACAO.NRORG
                    JOIN PARCNEGOCIO
                        ON PARCNEGOCIO.NRPARCNEGOCIO = FCT_APURACAO.NRPARCNEGOCIO
                    AND PARCNEGOCIO.NRORG = FCT_APURACAO.NRORG
                    WHERE FCT_APURACAO.DTINCLUSAO BETWEEN NVL(:DTINICIO, SYSDATE-30) AND NVL(:DTFINAL, SYSDATE)
                        AND ((FCT_APURACAO.NRPARCNEGOCIO IN (:NRPARCNEGOCIO)) OR (:NRPARCNEGOCIO IS NULL))
                    GROUP BY FCT_APURACAO.NRPARCNEGOCIO, PARCNEGOCIO.NMSECUNDARIPARC
                    ORDER BY VALOR DESC";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function getBillingScopeDetailed($parametros)
    {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);

        $sql = "SELECT FCT_CONTRATO.NRTIPOORCAMENTO, FCT_TIPOORCAMENTO.NMTIPOORCAMENTO, SUM(FCT_APURACAO.VRAPURACAO) AS VALOR
                    FROM FCT_FATURACONT
                    JOIN FCT_RELACAPURACAOFATURA
                    ON FCT_RELACAPURACAOFATURA.NRFATURACONT = FCT_FATURACONT.NRFATURACONT
                    AND FCT_RELACAPURACAOFATURA.NRORG = FCT_FATURACONT.NRORG
                    JOIN FCT_APURACAO
                    ON FCT_RELACAPURACAOFATURA.NRAPURACAO = FCT_APURACAO.NRAPURACAO
                    AND FCT_RELACAPURACAOFATURA.NRORG = FCT_APURACAO.NRORG
                    JOIN FCT_RELACAGRUPCONTFAT
                    ON FCT_RELACAGRUPCONTFAT.NRFATURACONT = FCT_FATURACONT.NRFATURACONT
                    AND FCT_RELACAGRUPCONTFAT.NRORG = FCT_FATURACONT.NRORG
                    JOIN FCT_CONTRATO
                    ON FCT_CONTRATO.NRSEQCONTRATO = FCT_RELACAGRUPCONTFAT.NRSEQCONTRATO
                    AND FCT_CONTRATO.NRORG = FCT_RELACAGRUPCONTFAT.NRORG
                    JOIN FCT_TIPOORCAMENTO
                    ON FCT_TIPOORCAMENTO.NRTIPOORCAMENTO = FCT_CONTRATO.NRTIPOORCAMENTO
                    AND FCT_TIPOORCAMENTO.NRORG = FCT_CONTRATO.NRORG
                WHERE FCT_APURACAO.DTINCLUSAO BETWEEN NVL(:DTINICIO, SYSDATE-30) AND NVL(:DTFINAL, SYSDATE)
                    AND ((FCT_CONTRATO.NRTIPOORCAMENTO IN (:NRTIPOORCAMENTO)) OR (:NRTIPOORCAMENTO IS NULL))
                GROUP BY FCT_CONTRATO.NRTIPOORCAMENTO, FCT_TIPOORCAMENTO.NMTIPOORCAMENTO
                ORDER BY VALOR DESC";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function getPartners()
    {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);


        $sql = "SELECT NRPARCNEGOCIO, NMPRINCIPALPARC
                    FROM PARCNEGOCIO
                    WHERE IDATIVO = 'S'";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getScopes()
    {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);


        $sql = "SELECT NMTIPOORCAMENTO, NRTIPOORCAMENTO
                    FROM FCT_TIPOORCAMENTO
                    WHERE IDATIVO = 'S'
                    ORDER BY NMTIPOORCAMENTO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function amountOfProposalAccepted($parametros)
    {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);

        $sql = "SELECT GRAF.*
                    FROM (SELECT FCT_REFEORCACONT.NRTIPOORCAMENTO, FCT_TIPOORCAMENTO.NMTIPOORCAMENTO, COUNT(FCT_REFEORCACONT.NRSEQORCAMENTO) AS QUANTIDADE
                            FROM FCT_REFEORCACONT
                            JOIN FCT_TIPOORCAMENTO
                            ON FCT_TIPOORCAMENTO.NRTIPOORCAMENTO = FCT_REFEORCACONT.NRTIPOORCAMENTO
                            AND FCT_TIPOORCAMENTO.NRORG = FCT_REFEORCACONT.NRORG
                        WHERE FCT_REFEORCACONT.DTINCLUSAO BETWEEN NVL(:DTINICIO, SYSDATE-30) AND NVL(:DTFINAL, SYSDATE)
                        GROUP BY FCT_REFEORCACONT.NRTIPOORCAMENTO, FCT_TIPOORCAMENTO.NMTIPOORCAMENTO
                        ORDER BY QUANTIDADE DESC) GRAF
                        WHERE ROWNUM <= 5  ";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function valueOfAcceptedProposal($parametros)
    {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);


        $sql = "SELECT GRAF.*
                    FROM (SELECT FCT_REFEORCACONT.NRTIPOORCAMENTO, FCT_TIPOORCAMENTO.NMTIPOORCAMENTO, SUM(FCT_ORCAMENTO.VRORCAMENTO) AS VALOR
                            FROM FCT_ORCAMENTO
                            JOIN FCT_REFEORCACONT
                            ON FCT_REFEORCACONT.NRSEQORCAMENTO = FCT_ORCAMENTO.NRSEQORCAMENTO
                            AND FCT_REFEORCACONT.NRORG = FCT_ORCAMENTO.NRORG
                            JOIN FCT_TIPOORCAMENTO
                            ON FCT_TIPOORCAMENTO.NRTIPOORCAMENTO = FCT_REFEORCACONT.NRTIPOORCAMENTO
                            AND FCT_TIPOORCAMENTO.NRORG = FCT_REFEORCACONT.NRORG
                        WHERE FCT_REFEORCACONT.DTINCLUSAO BETWEEN NVL(:DTINICIO, SYSDATE-30) AND NVL(:DTFINAL, SYSDATE)
                        GROUP BY FCT_REFEORCACONT.NRTIPOORCAMENTO, FCT_TIPOORCAMENTO.NMTIPOORCAMENTO
                        ORDER BY VALOR DESC) GRAF
                        WHERE ROWNUM <= 5 ";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function valueOfAcceptedProposalXBusinessPartner($parametros)
    {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);

        $sql = "SELECT GRAF.*
                    FROM (SELECT FCT_ORCAMENTO.NRPARCNEGOCIO, PARCNEGOCIO.NMSECUNDARIPARC, SUM(FCT_ORCAMENTO.VRORCAMENTO) AS VALOR
                            FROM FCT_ORCAMENTO
                            JOIN PARCNEGOCIO
                            ON PARCNEGOCIO.NRPARCNEGOCIO = FCT_ORCAMENTO.NRPARCNEGOCIO
                            AND PARCNEGOCIO.NRORG = FCT_ORCAMENTO.NRORG
                        WHERE FCT_ORCAMENTO.DTACEITEORCA BETWEEN NVL(:DTINICIO, SYSDATE-30) AND NVL(:DTFINAL, SYSDATE)
                            AND IDSITUACAOORCAMENTO =  'ACEITO'
                        GROUP BY FCT_ORCAMENTO.NRPARCNEGOCIO, PARCNEGOCIO.NMSECUNDARIPARC
                        ORDER BY VALOR DESC) GRAF
                        WHERE ROWNUM <= 15 ";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function getContractItemsDetailed($parametros)
    {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);

        $sql = "SELECT FCT_ITEMCONTRATO.CDSERVORCA, FCT_ITEMCONTRATO.NMITEMCONTRATO, SUM(FCT_ITFATURACONT.VRFATURADO) AS VALOR
                    FROM FCT_FATURACONT
                    JOIN FCT_RELACAPURACAOFATURA
                        ON FCT_RELACAPURACAOFATURA.NRFATURACONT = FCT_FATURACONT.NRFATURACONT
                    AND FCT_RELACAPURACAOFATURA.NRORG = FCT_FATURACONT.NRORG
                    JOIN FCT_APURACAO
                        ON FCT_RELACAPURACAOFATURA.NRAPURACAO = FCT_APURACAO.NRAPURACAO
                    AND FCT_RELACAPURACAOFATURA.NRORG = FCT_APURACAO.NRORG
                    JOIN FCT_RELACAGRUPCONTFAT
                        ON FCT_RELACAGRUPCONTFAT.NRFATURACONT = FCT_FATURACONT.NRFATURACONT
                    AND FCT_RELACAGRUPCONTFAT.NRORG = FCT_FATURACONT.NRORG
                    JOIN FCT_CONTRATO
                        ON FCT_CONTRATO.NRSEQCONTRATO = FCT_RELACAGRUPCONTFAT.NRSEQCONTRATO
                    AND FCT_CONTRATO.NRORG = FCT_RELACAGRUPCONTFAT.NRORG
                    JOIN FCT_ITFATURACONT
                        ON FCT_ITFATURACONT.NRSEQCONTRATO = FCT_CONTRATO.NRSEQCONTRATO
                    AND FCT_ITFATURACONT.NRFATURACONT = FCT_FATURACONT.NRFATURACONT
                    AND FCT_ITFATURACONT.NRORG = FCT_CONTRATO.NRORG
                    JOIN FCT_ITEMCONTRATO
                        ON FCT_ITEMCONTRATO.NRITEMOCONTRATO = FCT_ITFATURACONT.NRITEMOCONTRATO
                    AND FCT_ITEMCONTRATO.NRORG = FCT_ITFATURACONT.NRORG
                    WHERE FCT_APURACAO.DTINCLUSAO BETWEEN NVL(:DTINICIO, SYSDATE-30) AND NVL(:DTFINAL, SYSDATE)
                    AND ((FCT_ITEMCONTRATO.CDSERVORCA IN (:CDSERVORCA)) OR (:CDSERVORCA IS NULL))
                    GROUP BY FCT_ITEMCONTRATO.CDSERVORCA, FCT_ITEMCONTRATO.NMITEMCONTRATO
                    ORDER BY VALOR DESC";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function getContractItems()
    {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $this->connection->executeStatement($sqlAlter);

        $sql = " SELECT FCT_ITEMCONTRATO.CDSERVORCA, FCT_ITEMCONTRATO.NMITEMCONTRATO
                    FROM FCT_ITEMCONTRATO
                    WHERE IDATIVO = 'S'
                    ORDER BY FCT_ITEMCONTRATO.NMITEMCONTRATO";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }
}
