<?php

namespace SM\Service;

use SM\Factory\Sm00001001DocumentoPropostaFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use SM\Service\FileServerService;
use SM\Util\Utilities;
use SM\Util\Procedure\FctAtualizaDocumento;

class Sm00001001DocumentoPropostaService
{
    protected $documentoPropostaFactory;
    protected $Environment;
    protected $newCode;
    protected $fileServerService;
    protected $connection;
    protected $fileServerUrl;

    public function __construct(EntityManager $entityManager, Sm00001001DocumentoPropostaFactory $documentoPropostaFactory, Environment $Environment, NewCode $newCode, FileServerService $fileServerService, $fileServerUrl)
    {
        $this->documentoPropostaFactory = $documentoPropostaFactory;
        $this->connection             = $entityManager->getConnection();
        $this->Environment            = $Environment;
        $this->newCode                = $newCode;
        $this->fileServerService      = $fileServerService;
        $this->fileServerUrl          = $fileServerUrl;
    }

    public function getDocumentoProposta()
    {
        return $this->documentoPropostaFactory->getDocumentoProposta();
    }

    public function getProposta()
    {
        return $this->documentoPropostaFactory->getProposta();
    }

    public function getTabAnexoDocumentoProposta($params)
    {
        $paramsaux = array(
            "NRSEQORCADOC"   => $params['NRSEQORCADOC']
        );
        return $this->documentoPropostaFactory->getTabAnexoDocumentoProposta($paramsaux);
    }

    public function getPropostasDocumento($parametro)
    {
        return $this->documentoPropostaFactory->getPropostasDocumento($parametro);
    }

    public function inserirDocumentoProposta($parametros)
    {
        $this->connection->beginTransaction();
        $cdoperador = $this->Environment->getCdOperador();
        $nrorg = $this->Environment->getNrOrg();
       
        $nrseqorcadoc = $this->newCode->getCodeByTableName("NRSEQORCADOC", $nrorg, 1, 10, true);

        $paramsDocumentoProposta = array (
            "NRSEQORCADOC"    => $nrseqorcadoc,
            "NRSEQORCAMENTO"  => $parametros["NRSEQORCAMENTO"],
            "NRTIPOORCAMENTO" => $parametros["NRTIPOORCAMENTO"],
            "VRTAMANHOLOGO"   => $parametros["VRTAMANHOLOGO"],
            "NRSEQMODDOCFCT"  => $parametros["NRSEQMODDOCFCT"],
            "IDATIVO"         => "S",
        );

        $this->documentoPropostaFactory->inserirDocumentoProposta($paramsDocumentoProposta);
        
        $nrorcamentodocsitu = $this->newCode->getCodeByTableName("FCT_ORCAMENTODOCSITU", $nrorg, 1, 10, true);
        $situacoes = implode(",", $parametros["IDSITUACAOORCAMENTO"]);
        
        $paramsSituacaoProposta = [
            "NRORCAMENTODOCSITU"   => $nrorcamentodocsitu,
            "IDSITUACAOORCAMENTO"  => $situacoes,
            "NRSEQORCADOC"        => $nrseqorcadoc,
            "IDATIVO"             => "S",
            "NRORG"               => $nrorg,
            "NRORGINCLUSAO"       => $nrorg,
            "CDOPERINCLUSAO"      => $cdoperador
        ];

        $this->documentoPropostaFactory->inserirSituacaoDocumentoProposta($paramsSituacaoProposta);
        
        $this->connection->commit();
    }

    public function editarDocumentoProposta($parametros)
    {
        $this->connection->beginTransaction();
        $cdoperador = $this->Environment->getCdOperador();
        $nrorg = $this->Environment->getNrOrg();

        $paramsEditDocProp = array (
            "VRTAMANHOLOGO" => $parametros["VRTAMANHOLOGO"],
            "CDOPERULTATU"  => $cdoperador,
            "NRSEQORCADOC"  => $parametros["NRSEQORCADOC"]
        );

        $this->documentoPropostaFactory->updateDocumentoProposta($paramsEditDocProp);
        
        $params = [
            "NRSEQORCADOC" => $parametros["NRSEQORCADOC"]
        ];

        $this->documentoPropostaFactory->excluirSituacoesDocumentoProposta($params);

        $situacoes = $parametros["IDSITUACAOORCAMENTO"];

        $paramsAux = [
            "NRORCAMENTODOCSITU"  => null,
            "NRSEQORCADOC"        => $parametros["NRSEQORCADOC"],
            "IDSITUACAOORCAMENTO" => null,
            "IDATIVO"             => "S",
            "NRORG"               => $nrorg,
            "NRORGINCLUSAO"       => $nrorg,
            "CDOPERINCLUSAO"      => $cdoperador
        ];
        foreach ($situacoes as $situacao) {
            $paramsAux["NRORCAMENTODOCSITU"] = $this->newCode->getCodeByTableName("FCT_ORCAMENTODOCSITU", $nrorg, 1, 10, true);
            $paramsAux["IDSITUACAOORCAMENTO"] = $situacao;
            $this->documentoPropostaFactory->inserirSituacoesDocumentoProposta($paramsAux);
        }

        $this->connection->commit();
    }

    public function deleteDocumentoProposta($parametros)
    {
        $this->connection->beginTransaction();
        try {
            foreach ($parametros as $documentoProposta) {
                $dataParam = array( "NRSEQORCADOC" => $documentoProposta["NRSEQORCADOC"],);
                $this->documentoPropostaFactory->deleteDocumentoProposta($dataParam);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function getEscopoFaturamento($parametro)
    {
        return $this->documentoPropostaFactory->getEscopoFaturamento($parametro);
    }

    public function inserirAnexoDocumentoProposta($parametros)
    {
        $nrorg = $this->Environment->getNrorg();
        $cdoperador = $this->Environment->getCdOperador();
        $this->connection->beginTransaction();

        $paramsauxdocpropidioma = array(
            "NRSEQORCADOC"        => $parametros['NRSEQORCADOC'],
            "CDIDIOM"             => $parametros['CDIDIOM'],
            "NRORCAMENTODOCIDIOMA" => $parametros['NRORCAMENTODOCIDIOMA'],
        );

        $valor = $this->documentoPropostaFactory->validaDocPropIdioma($paramsauxdocpropidioma);

        if ($valor[0]["QTD"] > 0) {
            throw new \Exception("EXISTE");
        }
        
        try {
            if (count($parametros['ARQUIVO']) > 0) {
                $dados = $this->fileServerService->uploadFiles($parametros['ARQUIVO'], 'anexo_modelo_documento_proposta');
                $dados[0]["size"] = $dados[0]["size"]/1024;
            } else {
                $dados = [[
                    "path" => $parametros["DSCAMINHOARQ"],
                    "size" => $parametros["VRTAMANHO"],
                    "name" => $parametros["NMARQUIVO"],
                    "type" => $parametros["DSTIPO"],
                ]];
            }

            if ($parametros['NRORCAMENTODOCIDIOMA'] == null) {
                $nrorcamentodocidioma = $this->newCode->getCodeByTableName("FCT_ORCAMENTODOCIDIOMA", $nrorg, 1, 10, true);
                $params = array(
                    "NRORCAMENTODOCIDIOMA"  => $nrorcamentodocidioma,
                    "NRSEQORCADOC"          => $parametros['NRSEQORCADOC'],
                    "CDIDIOM"               => $parametros['CDIDIOM'],
                    "IDATIVO"               => $parametros['IDATIVO'],
                    "NMARQUIVO"             => $dados[0]['name'],
                    "DSCAMINHOARQ"          => $dados[0]['path'],
                    "DSTIPO"                => $dados[0]['type'],
                    "VRTAMANHO"             => $dados[0]['size'],
                    "NRORG"                 => $nrorg,
                    "NRORGINCLUSAO"         => $nrorg,
                    "CDOPERINCLUSAO"        => $cdoperador,
                );
                $this->documentoPropostaFactory->inserirModeloDocumentoProposta($params);
            } else {
                $params = array(
                    "NRORCAMENTODOCIDIOMA" => $parametros['NRORCAMENTODOCIDIOMA'],
                    "NRSEQORCADOC"    => $parametros['NRSEQORCADOC'],
                    "CDIDIOM"           => $parametros['CDIDIOM'],
                    "IDATIVO"           => $parametros['IDATIVO'],
                    "NMARQUIVO"         => $dados[0]["name"],
                    "DSCAMINHOARQ"      => $dados[0]["path"],
                    "DSTIPO"            => $dados[0]["type"],
                    "VRTAMANHO"         => $dados[0]["size"],
                    "NRORGULTATU"       => $nrorg,
                    "CDOPERULTATU"      => $cdoperador
                );
                $this->documentoPropostaFactory->updateModeloDocumentoProposta($params);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function downloadAnexoModeloDocumentoProposta($nrorcamentodocidioma)
    {
        $param = array(
                "NRORCAMENTODOCIDIOMA" => $nrorcamentodocidioma
        );

        $dados = $this->documentoPropostaFactory->getAnexoProposta($param);
        $url = $this->fileServerUrl."/files/".$dados["data"][0]['DSCAMINHOARQ'];
        $nomeArquivo = $dados["data"][0]['NMARQUIVO'];
        $tipo = $dados["data"][0]['DSTIPO'];
        $tamanho = $dados["data"][0]['VRTAMANHO']*1024;

        $file = @file_get_contents($url);
        if ($file) {
            Utilities::downloadArquivoFileServer($url, $nomeArquivo, $tipo, $tamanho);
        } else {
            $this->downloadDocFileServer($nrorcamentodocidioma);
        }
    }

    public function downloadDocFileServer($nrorcamentodocidioma)
    {
        $paramsAux = array (
            "NRORCAMENTODOCIDIOMA" => $nrorcamentodocidioma,
        );

        $documento = $this->documentoPropostaFactory->getDocumentoPropostaIdioma($paramsAux);
        if (!empty($documento["data"][0]["DSCAMINHOARQ"])) {
            $microtime = microtime(true);
            $microtime = str_replace(".", "_", $microtime);
            
            $url = $this->fileServerUrl."/files/".$documento["data"][0]['DSCAMINHOARQ'];
            $fileName  = $microtime . "_" . str_replace(",", "_", $documento["data"][0]["NMARQUIVO"]);
            $tipo = $documento["data"][0]['DSTIPO'];
            $tamanho = $documento["data"][0]['VRTAMANHO']*1024;

            Utilities::downloadArquivoFileServer($url, $fileName, $tipo, $tamanho);
        }
    }

    public function deletarAnexoDocumentoProposta($params)
    {
        $this->connection->beginTransaction();
        try {
            foreach ($params as $anexo) {
                $dataParam = array(
                    "NRORCAMENTODOCIDIOMA" => $anexo["NRORCAMENTODOCIDIOMA"],
                );
                if (!empty($anexo['DSCAMINHOARQ'])) {
                    $this->fileServerService->deleteFile($anexo['DSCAMINHOARQ']);
                }
                $this->documentoPropostaFactory->deletarAnexoDocumentoProposta($dataParam);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function limparAnexoModeloDocumentoProposta($parametros)
    {
        $row = $parametros["row"];
        $param = array(
            "NRORCAMENTODOCIDIOMA" => $row["NRORCAMENTODOCIDIOMA"]
        );
        $this->fileServerService->deleteFile($row["DSCAMINHOARQ"]);
        $this->documentoPropostaFactory->limparAnexoModeloDocumentoProposta($param);
    }

    public function atualizarAnexoModeloDocumentoProposta($parametros)
    {
        $this->connection->beginTransaction();
        $nrorg = $this->Environment->getNrorg();
        $cdoperador = $this->Environment->getCdOperador();
        try {
            $paramsAuxGet = array (
                "NRSEQORCADOC" => $parametros["params"]["NRSEQORCADOC"],
                "NRORG"        => $nrorg
            );
            $documentos = $this->documentoPropostaFactory->getAnexoDocumentoProposta($paramsAuxGet);
            foreach ($documentos as $documento) {
                if (!empty($documento[0]["DSCAMINHOARQ"])) {
                    $this->fileServerService->deleteFile($documento[0]["DSCAMINHOARQ"]);
                }
            }

            $paramsAuxLimpar = array (
                "NRSEQORCADOC" => $parametros["params"]["NRSEQORCADOC"],
                "NRORG"        => $nrorg
            );

            $this->documentoPropostaFactory->limparAnexoDaProposta($paramsAuxLimpar);
            $nrseqorcadoc = $parametros["params"]["NRSEQORCADOC"];
            $nrseqmoddocfct = $parametros["params"]["NRSEQMODDOCFCT"];
            $procedure = new FctAtualizaDocumento($this->connection);
            $procedure->executar($nrseqorcadoc, "P", $nrseqmoddocfct, $nrorg, $cdoperador);
            
            $paramsAux = array (
                "NRSEQORCADOC" => $nrseqorcadoc,
                "NRORG"        => $nrorg
            );
            $documentos = $this->documentoPropostaFactory->getAnexoDocumentoProposta($paramsAux);
            foreach ($documentos["data"] as $documento) {
                $nomeArquivo   = $documento["NMARQUIVO"];
                $tipo          = $documento["DSTIPO"];
                $tamanhoBytes  = $documento["VRTAMANHO"] * 1024;
                $path           = $documento["DSCAMINHOARQ"];
                $url = $this->fileServerUrl."/files/".$path;
                $conteudo = $this->fileServerService->getDocumentoFileServer($url, $nrorg);
                if ($conteudo !== false) {
                    $file = $this->fileServerService->uploadFileServer('anexo_documento_proposta', $nomeArquivo, $conteudo, $tamanhoBytes, $tipo);
                    $caminhoNovo = $file["path"];
                    $params = array(
                        "DSCAMINHOARQ" => $caminhoNovo,
                        "CDOPERULTATU" => $cdoperador,
                        "NRORGULTATU"  => $nrorg,
                        "NRSEQORCADOC" => $nrseqorcadoc,
                        "NRORG"        => $nrorg
                    );
                    $this->documentoPropostaFactory->atualizarCaminhoDocumentoProposta($params);
                }
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}
