import { IEventParam, Metadata } from '@zeedhi/core';
import { Button, Modal, ModalService } from '@zeedhi/common';
import {
    TekGrid,
    TekRestDatasource, TekTreeGrid,
} from '@zeedhi/teknisa-components-common';

export class MapaFaturamentoController {
    public currentRow : any = {};

    public visibilidadeGrid: boolean = true;

    public tituloServico: string = '';

    get visibilidadeFrame() {
        return !this.visibilidadeGrid;
    }

    public rowClick({ row }: any) {
        this.visibilidadeGrid = false;
        this.currentRow = row;
        this.tituloServico = row.NMSERVORCA;
    
        Metadata.getInstance<TekGrid>('tek_grid_parceiros').datasource.setFilter({
            CDSERVORCA: row.CDSERVORCA,
        });
    
        Metadata.getInstance<TekGrid>('tek_grid_contrato').datasource.updateData([]);
    }

    public openFilter({ component }: any) {
        const filterButton = Metadata.getInstance<Button>(`${component.name}_filterButton`);
        filterButton.click({} as Event, {} as HTMLElement);
    }

    public voltarPaginaInicial() {
        this.visibilidadeGrid = true;
    }

    public rowClickCliente({ row }: any) {
        Metadata.getInstance<TekGrid>('tek_grid_contrato').datasource.setFilter({
            CDSERVORCA: row.CDSERVORCA,
            NRPARCNEGOCIO: row.NRPARCNEGOCIO,
        });
    }

    public colorDiferenca1({ row }: any) {
        let color;

        if (row.DIFERENCA1 === 0) {
            color = { color: '#000000' };
        } else if (row.DIFERENCA1 < 0) {
            color = { color: '#FF0000' };
        } else if (row.DIFERENCA1 > 0) {
            color = { color: '#008000' };
        }

        return color;
    }

    public colorDiferenca2({ row }: any) {
        let color;

        if (row.DIFERENCA2 === 0) {
            color = { color: '#000000' };
        } else if (row.DIFERENCA2 < 0) {
            color = { color: '#FF0000' };
        } else if (row.DIFERENCA2 > 0) {
            color = { color: '#008000' };
        }

        return color;
    }

    public colorDiferenca3({ row }: any) {
        let color;

        if (row.DIFERENCA3 === 0) {
            color = { color: '#000000' };
        } else if (row.DIFERENCA3 < 0) {
            color = { color: '#FF0000' };
        } else if (row.DIFERENCA3 > 0) {
            color = { color: '#008000' };
        }

        return color;
    }

    public colorDesv1({ row }: any) {
        let color;

        if (row.DESVIO1 === 0) {
            color = { color: '#000000' };
        } else if (row.DESVIO1 < 0) {
            color = { color: '#FF0000' };
        } else if ((row.DESVIO1 > 0) && (row.DESVIO1 < 200)) {
            color = { color: '#008B00' };
        } else if (row.DESVIO1 > 200) {
            color = { color: '#FF7F00' };
        }

        return color;
    }

    public colorDesv2({ row }: any) {
        let color;

        if (row.DESVIO2 === 0) {
            color = { color: '#000000' };
        } else if (row.DESVIO2 < 0) {
            color = { color: '#FF0000' };
        } else if ((row.DESVIO2 > 0) && (row.DESVIO2 < 200)) {
            color = { color: '#008B00' };
        } else if (row.DESVIO2 > 200) {
            color = { color: '#FF7F00' };
        }

        return color;
    }

    public colorDesv3({ row }: any) {
        let color;

        if (row.DESVIO3 === 0) {
            color = { color: '#000000' };
        } else if (row.DESVIO3 < 0) {
            color = { color: '#FF0000' };
        } else if ((row.DESVIO3 > 0) && (row.DESVIO3 < 200)) {
            color = { color: '#008B00' };
        } else if (row.DESVIO3 > 200) {
            color = { color: '#FF7F00' };
        }

        return color;
    }

    public colunaCinza() {
        return 'coluna-cinza';
    }

    public filtrarCliente({ component }: any) {
        component.datasource.setFilter({
            tipoParc: ['CLIENTE'],
        });
    }

    public filterParent({ component }: IEventParam<TekTreeGrid>) {
        delete component.datasource.filter[component.parentField];

        if (!(component.datasource instanceof TekRestDatasource)) {
            return;
        }
        if (Object.keys(component.datasource.dynamicFilter).length === 0) {
            component.fetchOnDemand = true;
            component.treeDataStructure.fetchOnDemand = true;
        } else {
            component.fetchOnDemand = false;
            component.treeDataStructure.fetchOnDemand = false;
        }
    }

    // Funções referente à exportação de todos os dados
    private fullscreenModal!: Modal;
    
    public clicks: boolean = true;

    public async openFullScreenModal() {
        this.fullscreenModal?.destroy();
        this.fullscreenModal = await ModalService.createFromJson('sm_mapa_faturamento/modal/sm_modal_dados_completos', true);
        this.fullscreenModal.show();
    }
    
    public closeFullScreenModal() {
        this.fullscreenModal.hide();
        this.fullscreenModal?.destroy();
    }

    public onMountedGrid() {
        const gridPrincipal = Metadata.getInstance<TekGrid>('tek_grid_mapa_faturamento');
        let gridSecundario = null;
        try {
            gridSecundario = Metadata.getInstance<TekGrid>('tek_grid_dados_completos');
        } catch (error) {
            gridSecundario = null;
        }
    
        if (gridSecundario) {
            (gridSecundario.datasource as TekRestDatasource).dynamicFilter = (gridPrincipal.datasource as TekRestDatasource).dynamicFilter;
            gridSecundario.datasource.get();
        }
    }
}
