import {
    Http, Metadata,
} from '@zeedhi/core';
import {
    LoadingService, Select, IGridEvent, DialogService,
} from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';

export class Sm00054001ReducaoQuantidadeMedidaController {
    public adicionarReducaoQuantidadeMedidaOperador() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-operador-reducao');
        const newId = 0;
        grid.addNewRow({ NRALTERAQTMEDOPER: newId }, 'start');
    }

    public async inserirReducaoQuantidadeMedidaOperador({ event }: IGridEvent) {
        event!.preventDefault();
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-operador-reducao');
        const operadores = grid.getEditedRows();

        const CurrentRow = grid.datasource.currentRow;
        const UniqueKey = grid.datasource.uniqueKey;
        const currentKey = CurrentRow[UniqueKey];
        const conlumnCDOPERADOR = 'CDOPERADOR';
        const selectComp = grid.getComponent<Select>(currentKey, conlumnCDOPERADOR);

        if (selectComp.validate()) {
            LoadingService.show();
            Http.post('/insertNewReducaoQuantidadeMedidaOperador', operadores)
                .then(async () => {
                    await grid.cancelEditedRows();
                    await grid.reload();
                    Utilities.showSuccessMessage();
                    grid.datasource.get();
                }).catch((error) => {
                    if (error.response.data.error === 'EXISTE') {
                        Utilities.showDialogMessage('error', 'Operação bloqueada!', 'O Operador informado já está cadastrado.');
                    } else {
                        Utilities.showErrorMessage(error);
                    }
                }).finally(() => {
                    LoadingService.hide();
                });
            LoadingService.hide();
        } else {
            Utilities.alertMessage('Preencha todos os campos obrigatórios', 'error');
        }
    }

    public showConfirmDeleteMessageOperador({ event }: any) {
        event!.preventDefault();
        DialogService.show({
            name: 'buttons-dialog-operador',
            type: 'warning',
            title: 'Excluir Registro',
            text: 'Deseja realmente excluir todos os registros selecionados?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deletarReducaoQuantidadeMedidaOperador();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public async deletarReducaoQuantidadeMedidaOperador() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-operador-reducao');
        LoadingService.show();
        try {
            await Http.post('/deletarReducaoQuantidadeMedidaOperador', grid.selectedRows);
            await grid.cancelEditedRows();
            await grid.reload();
            Utilities.showSuccessMessage();
        } catch (e) {
            Utilities.showErrorMessage(e);
        }
        LoadingService.hide();
    }
}
